"""
Exports WIDE_EASTASIAN table keyed by supporting unicode version level.

This code generated by wcwidth/bin/update-tables.py on 2025-09-19 15:55:08 UTC.
"""

WIDE_EASTASIAN = {
    "4.1.0": (
        # Source: EastAsianWidth-4.1.0.txt
        # Date: 2005-03-17, 15:21:00 PST [KW]
        #
        (
            0x01100,
            0x01159,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Yeorinhi
        (
            0x0115F,
            0x0115F,
        ),  # Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312C,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Gn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031B7,
        ),  # Ideographic Annotation L..Bopomofo Final Letter H
        (
            0x031C0,
            0x031CF,
        ),  # Cjk Stroke T            ..Cjk Stroke N
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03243,
        ),  # Parenthesized Ideograph ..Parenthesized Ideograph
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DB5,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x09FBB,
        ),  # Cjk Unified Ideograph-4e..Cjk Unified Ideograph-9f
        (
            0x0A000,
            0x0A48C,
        ),  # Yi Syllable It          ..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FA2D,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FA30,
            0x0FA6A,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FA70,
            0x0FAD9,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "5.0.0": (
        # Source: EastAsianWidth-5.0.0.txt
        # Date: 2006-02-15, 14:39:00 PST [KW]
        #
        (
            0x01100,
            0x01159,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Yeorinhi
        (
            0x0115F,
            0x0115F,
        ),  # Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312C,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Gn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031B7,
        ),  # Ideographic Annotation L..Bopomofo Final Letter H
        (
            0x031C0,
            0x031CF,
        ),  # Cjk Stroke T            ..Cjk Stroke N
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03243,
        ),  # Parenthesized Ideograph ..Parenthesized Ideograph
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DB5,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x09FBB,
        ),  # Cjk Unified Ideograph-4e..Cjk Unified Ideograph-9f
        (
            0x0A000,
            0x0A48C,
        ),  # Yi Syllable It          ..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FA2D,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FA30,
            0x0FA6A,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FA70,
            0x0FAD9,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "5.1.0": (
        # Source: EastAsianWidth-5.1.0.txt
        # Date: 2008-03-20, 17:42:00 PDT [KW]
        #
        (
            0x01100,
            0x01159,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Yeorinhi
        (
            0x0115F,
            0x0115F,
        ),  # Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031B7,
        ),  # Ideographic Annotation L..Bopomofo Final Letter H
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03243,
        ),  # Parenthesized Ideograph ..Parenthesized Ideograph
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DB5,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x09FC3,
        ),  # Cjk Unified Ideograph-4e..Cjk Unified Ideograph-9f
        (
            0x0A000,
            0x0A48C,
        ),  # Yi Syllable It          ..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FA2D,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FA30,
            0x0FA6A,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FA70,
            0x0FAD9,
        ),  # Cjk Compatibility Ideogr..Cjk Compatibility Ideogr
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "5.2.0": (
        # Source: EastAsianWidth-5.2.0.txt
        # Date: 2009-06-09, 17:47:00 PDT [KW]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031B7,
        ),  # Ideographic Annotation L..Bopomofo Final Letter H
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x1F200,
            0x1F200,
        ),  # Square Hiragana Hoka
        (
            0x1F210,
            0x1F231,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "6.0.0": (
        # Source: EastAsianWidth-6.0.0.txt
        # Date: 2010-08-17, 12:17:00 PDT [KW]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x1B000,
            0x1B001,
        ),  # Katakana Letter Archaic ..Hiragana Letter Archaic
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23A,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "6.1.0": (
        # Source: EastAsianWidth-6.1.0.txt
        # Date: 2011-09-19, 18:46:00 GMT [KW]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x1B000,
            0x1B001,
        ),  # Katakana Letter Archaic ..Hiragana Letter Archaic
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23A,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "6.2.0": (
        # Source: EastAsianWidth-6.2.0.txt
        # Date: 2012-05-15, 18:30:00 GMT [KW]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x1B000,
            0x1B001,
        ),  # Katakana Letter Archaic ..Hiragana Letter Archaic
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23A,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "6.3.0": (
        # Source: EastAsianWidth-6.3.0.txt
        # Date: 2013-02-05, 20:09:00 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x1B000,
            0x1B001,
        ),  # Katakana Letter Archaic ..Hiragana Letter Archaic
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23A,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "7.0.0": (
        # Source: EastAsianWidth-7.0.0.txt
        # Date: 2014-02-28, 23:15:00 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x1B000,
            0x1B001,
        ),  # Katakana Letter Archaic ..Hiragana Letter Archaic
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23A,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "8.0.0": (
        # Source: EastAsianWidth-8.0.0.txt
        # Date: 2015-02-10, 21:00:00 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x1B000,
            0x1B001,
        ),  # Katakana Letter Archaic ..Hiragana Letter Archaic
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23A,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "9.0.0": (
        # Source: EastAsianWidth-9.0.0.txt
        # Date: 2016-05-27, 17:00:00 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312D,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Ih
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE0,
        ),  # Tangut Iteration Mark
        (
            0x17000,
            0x187EC,
        ),  # (nil)
        (
            0x18800,
            0x18AF2,
        ),  # Tangut Component-001    ..Tangut Component-755
        (
            0x1B000,
            0x1B001,
        ),  # Katakana Letter Archaic ..Hiragana Letter Archaic
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6F6,
        ),  # Scooter                 ..Canoe
        (
            0x1F910,
            0x1F91E,
        ),  # Zipper-mouth Face       ..Hand With Index And Midd
        (
            0x1F920,
            0x1F927,
        ),  # Face With Cowboy Hat    ..Sneezing Face
        (
            0x1F930,
            0x1F930,
        ),  # Pregnant Woman
        (
            0x1F933,
            0x1F93E,
        ),  # Selfie                  ..Handball
        (
            0x1F940,
            0x1F94B,
        ),  # Wilted Flower           ..Martial Arts Uniform
        (
            0x1F950,
            0x1F95E,
        ),  # Croissant               ..Pancakes
        (
            0x1F980,
            0x1F991,
        ),  # Crab                    ..Squid
        (
            0x1F9C0,
            0x1F9C0,
        ),  # Cheese Wedge
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "10.0.0": (
        # Source: EastAsianWidth-10.0.0.txt
        # Date: 2017-03-08, 02:00:00 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312E,
        ),  # Bopomofo Letter B       ..Bopomofo Letter O With D
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE1,
        ),  # Tangut Iteration Mark   ..Nushu Iteration Mark
        (
            0x17000,
            0x187EC,
        ),  # (nil)
        (
            0x18800,
            0x18AF2,
        ),  # Tangut Component-001    ..Tangut Component-755
        (
            0x1B000,
            0x1B11E,
        ),  # Katakana Letter Archaic ..Hentaigana Letter N-mu-m
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6F8,
        ),  # Scooter                 ..Flying Saucer
        (
            0x1F910,
            0x1F93E,
        ),  # Zipper-mouth Face       ..Handball
        (
            0x1F940,
            0x1F94C,
        ),  # Wilted Flower           ..Curling Stone
        (
            0x1F950,
            0x1F96B,
        ),  # Croissant               ..Canned Food
        (
            0x1F980,
            0x1F997,
        ),  # Crab                    ..Cricket
        (
            0x1F9C0,
            0x1F9C0,
        ),  # Cheese Wedge
        (
            0x1F9D0,
            0x1F9E6,
        ),  # Face With Monocle       ..Socks
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "11.0.0": (
        # Source: EastAsianWidth-11.0.0.txt
        # Date: 2018-05-14, 09:41:59 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE1,
        ),  # Tangut Iteration Mark   ..Nushu Iteration Mark
        (
            0x17000,
            0x187F1,
        ),  # (nil)
        (
            0x18800,
            0x18AF2,
        ),  # Tangut Component-001    ..Tangut Component-755
        (
            0x1B000,
            0x1B11E,
        ),  # Katakana Letter Archaic ..Hentaigana Letter N-mu-m
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6F9,
        ),  # Scooter                 ..Skateboard
        (
            0x1F910,
            0x1F93E,
        ),  # Zipper-mouth Face       ..Handball
        (
            0x1F940,
            0x1F970,
        ),  # Wilted Flower           ..Smiling Face With Smilin
        (
            0x1F973,
            0x1F976,
        ),  # Face With Party Horn And..Freezing Face
        (
            0x1F97A,
            0x1F97A,
        ),  # Face With Pleading Eyes
        (
            0x1F97C,
            0x1F9A2,
        ),  # Lab Coat                ..Swan
        (
            0x1F9B0,
            0x1F9B9,
        ),  # Emoji Component Red Hair..Supervillain
        (
            0x1F9C0,
            0x1F9C2,
        ),  # Cheese Wedge            ..Salt Shaker
        (
            0x1F9D0,
            0x1F9FF,
        ),  # Face With Monocle       ..Nazar Amulet
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "12.0.0": (
        # Source: EastAsianWidth-12.0.0.txt
        # Date: 2019-01-21, 14:12:58 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x032FE,
        ),  # Partnership Sign        ..Circled Katakana Wo
        (
            0x03300,
            0x04DBF,
        ),  # Square Apaato           ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x17000,
            0x187F7,
        ),  # (nil)
        (
            0x18800,
            0x18AF2,
        ),  # Tangut Component-001    ..Tangut Component-755
        (
            0x1B000,
            0x1B11E,
        ),  # Katakana Letter Archaic ..Hentaigana Letter N-mu-m
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D5,
        ),  # Hindu Temple
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FA,
        ),  # Scooter                 ..Auto Rickshaw
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F90D,
            0x1F971,
        ),  # White Heart             ..Yawning Face
        (
            0x1F973,
            0x1F976,
        ),  # Face With Party Horn And..Freezing Face
        (
            0x1F97A,
            0x1F9A2,
        ),  # Face With Pleading Eyes ..Swan
        (
            0x1F9A5,
            0x1F9AA,
        ),  # Sloth                   ..Oyster
        (
            0x1F9AE,
            0x1F9CA,
        ),  # Guide Dog               ..Ice Cube
        (
            0x1F9CD,
            0x1F9FF,
        ),  # Standing Person         ..Nazar Amulet
        (
            0x1FA70,
            0x1FA73,
        ),  # Ballet Shoes            ..Shorts
        (
            0x1FA78,
            0x1FA7A,
        ),  # Drop Of Blood           ..Stethoscope
        (
            0x1FA80,
            0x1FA82,
        ),  # Yo-yo                   ..Parachute
        (
            0x1FA90,
            0x1FA95,
        ),  # Ringed Planet           ..Banjo
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "12.1.0": (
        # Source: EastAsianWidth-12.1.0.txt
        # Date: 2019-03-31, 22:01:58 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031BA,
        ),  # Ideographic Annotation L..Bopomofo Letter Zy
        (
            0x031C0,
            0x031E3,
        ),  # Cjk Stroke T            ..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x04DBF,
        ),  # Partnership Sign        ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x17000,
            0x187F7,
        ),  # (nil)
        (
            0x18800,
            0x18AF2,
        ),  # Tangut Component-001    ..Tangut Component-755
        (
            0x1B000,
            0x1B11E,
        ),  # Katakana Letter Archaic ..Hentaigana Letter N-mu-m
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D5,
        ),  # Hindu Temple
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FA,
        ),  # Scooter                 ..Auto Rickshaw
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F90D,
            0x1F971,
        ),  # White Heart             ..Yawning Face
        (
            0x1F973,
            0x1F976,
        ),  # Face With Party Horn And..Freezing Face
        (
            0x1F97A,
            0x1F9A2,
        ),  # Face With Pleading Eyes ..Swan
        (
            0x1F9A5,
            0x1F9AA,
        ),  # Sloth                   ..Oyster
        (
            0x1F9AE,
            0x1F9CA,
        ),  # Guide Dog               ..Ice Cube
        (
            0x1F9CD,
            0x1F9FF,
        ),  # Standing Person         ..Nazar Amulet
        (
            0x1FA70,
            0x1FA73,
        ),  # Ballet Shoes            ..Shorts
        (
            0x1FA78,
            0x1FA7A,
        ),  # Drop Of Blood           ..Stethoscope
        (
            0x1FA80,
            0x1FA82,
        ),  # Yo-yo                   ..Parachute
        (
            0x1FA90,
            0x1FA95,
        ),  # Ringed Planet           ..Banjo
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "13.0.0": (
        # Source: EastAsianWidth-13.0.0.txt
        # Date: 2029-01-21, 18:14:00 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031E3,
        ),  # Ideographic Annotation L..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x04DBF,
        ),  # Partnership Sign        ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x17000,
            0x187F7,
        ),  # (nil)
        (
            0x18800,
            0x18CD5,
        ),  # Tangut Component-001    ..Khitan Small Script Char
        (
            0x18D00,
            0x18D08,
        ),  # (nil)
        (
            0x1B000,
            0x1B11E,
        ),  # Katakana Letter Archaic ..Hentaigana Letter N-mu-m
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D7,
        ),  # Hindu Temple            ..Elevator
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FC,
        ),  # Scooter                 ..Roller Skate
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F90C,
            0x1F93A,
        ),  # Pinched Fingers         ..Fencer
        (
            0x1F93C,
            0x1F945,
        ),  # Wrestlers               ..Goal Net
        (
            0x1F947,
            0x1F978,
        ),  # First Place Medal       ..Disguised Face
        (
            0x1F97A,
            0x1F9CB,
        ),  # Face With Pleading Eyes ..Bubble Tea
        (
            0x1F9CD,
            0x1F9FF,
        ),  # Standing Person         ..Nazar Amulet
        (
            0x1FA70,
            0x1FA74,
        ),  # Ballet Shoes            ..Thong Sandal
        (
            0x1FA78,
            0x1FA7A,
        ),  # Drop Of Blood           ..Stethoscope
        (
            0x1FA80,
            0x1FA86,
        ),  # Yo-yo                   ..Nesting Dolls
        (
            0x1FA90,
            0x1FAA8,
        ),  # Ringed Planet           ..Rock
        (
            0x1FAB0,
            0x1FAB6,
        ),  # Fly                     ..Feather
        (
            0x1FAC0,
            0x1FAC2,
        ),  # Anatomical Heart        ..People Hugging
        (
            0x1FAD0,
            0x1FAD6,
        ),  # Blueberries             ..Teapot
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "14.0.0": (
        # Source: EastAsianWidth-14.0.0.txt
        # Date: 2021-07-06, 09:58:53 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031E3,
        ),  # Ideographic Annotation L..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x04DBF,
        ),  # Partnership Sign        ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x17000,
            0x187F7,
        ),  # (nil)
        (
            0x18800,
            0x18CD5,
        ),  # Tangut Component-001    ..Khitan Small Script Char
        (
            0x18D00,
            0x18D08,
        ),  # (nil)
        (
            0x1AFF0,
            0x1AFF3,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan T
        (
            0x1AFF5,
            0x1AFFB,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan N
        (
            0x1AFFD,
            0x1AFFE,
        ),  # Katakana Letter Minnan N..Katakana Letter Minnan N
        (
            0x1B000,
            0x1B122,
        ),  # Katakana Letter Archaic ..Katakana Letter Archaic
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D7,
        ),  # Hindu Temple            ..Elevator
        (
            0x1F6DD,
            0x1F6DF,
        ),  # Playground Slide        ..Ring Buoy
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FC,
        ),  # Scooter                 ..Roller Skate
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F7F0,
            0x1F7F0,
        ),  # Heavy Equals Sign
        (
            0x1F90C,
            0x1F93A,
        ),  # Pinched Fingers         ..Fencer
        (
            0x1F93C,
            0x1F945,
        ),  # Wrestlers               ..Goal Net
        (
            0x1F947,
            0x1F9FF,
        ),  # First Place Medal       ..Nazar Amulet
        (
            0x1FA70,
            0x1FA74,
        ),  # Ballet Shoes            ..Thong Sandal
        (
            0x1FA78,
            0x1FA7C,
        ),  # Drop Of Blood           ..Crutch
        (
            0x1FA80,
            0x1FA86,
        ),  # Yo-yo                   ..Nesting Dolls
        (
            0x1FA90,
            0x1FAAC,
        ),  # Ringed Planet           ..Hamsa
        (
            0x1FAB0,
            0x1FABA,
        ),  # Fly                     ..Nest With Eggs
        (
            0x1FAC0,
            0x1FAC5,
        ),  # Anatomical Heart        ..Person With Crown
        (
            0x1FAD0,
            0x1FAD9,
        ),  # Blueberries             ..Jar
        (
            0x1FAE0,
            0x1FAE7,
        ),  # Melting Face            ..Bubbles
        (
            0x1FAF0,
            0x1FAF6,
        ),  # Hand With Index Finger A..Heart Hands
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "15.0.0": (
        # Source: EastAsianWidth-15.0.0.txt
        # Date: 2022-05-24, 17:40:20 GMT [KW, LI]
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x02FFB,
        ),  # Ideographic Description ..Ideographic Description
        (
            0x03000,
            0x03029,
        ),  # Ideographic Space       ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031E3,
        ),  # Ideographic Annotation L..Cjk Stroke Q
        (
            0x031F0,
            0x0321E,
        ),  # Katakana Letter Small Ku..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x04DBF,
        ),  # Partnership Sign        ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x17000,
            0x187F7,
        ),  # (nil)
        (
            0x18800,
            0x18CD5,
        ),  # Tangut Component-001    ..Khitan Small Script Char
        (
            0x18D00,
            0x18D08,
        ),  # (nil)
        (
            0x1AFF0,
            0x1AFF3,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan T
        (
            0x1AFF5,
            0x1AFFB,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan N
        (
            0x1AFFD,
            0x1AFFE,
        ),  # Katakana Letter Minnan N..Katakana Letter Minnan N
        (
            0x1B000,
            0x1B122,
        ),  # Katakana Letter Archaic ..Katakana Letter Archaic
        (
            0x1B132,
            0x1B132,
        ),  # Hiragana Letter Small Ko
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B155,
            0x1B155,
        ),  # Katakana Letter Small Ko
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D7,
        ),  # Hindu Temple            ..Elevator
        (
            0x1F6DC,
            0x1F6DF,
        ),  # Wireless                ..Ring Buoy
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FC,
        ),  # Scooter                 ..Roller Skate
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F7F0,
            0x1F7F0,
        ),  # Heavy Equals Sign
        (
            0x1F90C,
            0x1F93A,
        ),  # Pinched Fingers         ..Fencer
        (
            0x1F93C,
            0x1F945,
        ),  # Wrestlers               ..Goal Net
        (
            0x1F947,
            0x1F9FF,
        ),  # First Place Medal       ..Nazar Amulet
        (
            0x1FA70,
            0x1FA7C,
        ),  # Ballet Shoes            ..Crutch
        (
            0x1FA80,
            0x1FA88,
        ),  # Yo-yo                   ..Flute
        (
            0x1FA90,
            0x1FABD,
        ),  # Ringed Planet           ..Wing
        (
            0x1FABF,
            0x1FAC5,
        ),  # Goose                   ..Person With Crown
        (
            0x1FACE,
            0x1FADB,
        ),  # Moose                   ..Pea Pod
        (
            0x1FAE0,
            0x1FAE8,
        ),  # Melting Face            ..Shaking Face
        (
            0x1FAF0,
            0x1FAF8,
        ),  # Hand With Index Finger A..Rightwards Pushing Hand
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "15.1.0": (
        # Source: EastAsianWidth-15.1.0.txt
        # Date: 2023-07-28, 23:34:08 GMT
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x03029,
        ),  # Ideographic Description ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031E3,
        ),  # Ideographic Annotation L..Cjk Stroke Q
        (
            0x031EF,
            0x0321E,
        ),  # Ideographic Description ..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x04DBF,
        ),  # Partnership Sign        ..Cjk Unified Ideograph-4d
        (
            0x04E00,
            0x0A48C,
        ),  # Cjk Unified Ideograph-4e..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x17000,
            0x187F7,
        ),  # (nil)
        (
            0x18800,
            0x18CD5,
        ),  # Tangut Component-001    ..Khitan Small Script Char
        (
            0x18D00,
            0x18D08,
        ),  # (nil)
        (
            0x1AFF0,
            0x1AFF3,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan T
        (
            0x1AFF5,
            0x1AFFB,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan N
        (
            0x1AFFD,
            0x1AFFE,
        ),  # Katakana Letter Minnan N..Katakana Letter Minnan N
        (
            0x1B000,
            0x1B122,
        ),  # Katakana Letter Archaic ..Katakana Letter Archaic
        (
            0x1B132,
            0x1B132,
        ),  # Hiragana Letter Small Ko
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B155,
            0x1B155,
        ),  # Katakana Letter Small Ko
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D7,
        ),  # Hindu Temple            ..Elevator
        (
            0x1F6DC,
            0x1F6DF,
        ),  # Wireless                ..Ring Buoy
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FC,
        ),  # Scooter                 ..Roller Skate
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F7F0,
            0x1F7F0,
        ),  # Heavy Equals Sign
        (
            0x1F90C,
            0x1F93A,
        ),  # Pinched Fingers         ..Fencer
        (
            0x1F93C,
            0x1F945,
        ),  # Wrestlers               ..Goal Net
        (
            0x1F947,
            0x1F9FF,
        ),  # First Place Medal       ..Nazar Amulet
        (
            0x1FA70,
            0x1FA7C,
        ),  # Ballet Shoes            ..Crutch
        (
            0x1FA80,
            0x1FA88,
        ),  # Yo-yo                   ..Flute
        (
            0x1FA90,
            0x1FABD,
        ),  # Ringed Planet           ..Wing
        (
            0x1FABF,
            0x1FAC5,
        ),  # Goose                   ..Person With Crown
        (
            0x1FACE,
            0x1FADB,
        ),  # Moose                   ..Pea Pod
        (
            0x1FAE0,
            0x1FAE8,
        ),  # Melting Face            ..Shaking Face
        (
            0x1FAF0,
            0x1FAF8,
        ),  # Hand With Index Finger A..Rightwards Pushing Hand
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "16.0.0": (
        # Source: EastAsianWidth-16.0.0.txt
        # Date: 2024-04-30, 21:48:20 GMT
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02630,
            0x02637,
        ),  # Trigram For Heaven      ..Trigram For Earth
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x0268A,
            0x0268F,
        ),  # Monogram For Yang       ..Digram For Greater Yin
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x03029,
        ),  # Ideographic Description ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031E5,
        ),  # Ideographic Annotation L..(nil)
        (
            0x031EF,
            0x0321E,
        ),  # Ideographic Description ..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x0A48C,
        ),  # Partnership Sign        ..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x17000,
            0x187F7,
        ),  # (nil)
        (
            0x18800,
            0x18CD5,
        ),  # Tangut Component-001    ..Khitan Small Script Char
        (
            0x18CFF,
            0x18D08,
        ),  # (nil)
        (
            0x1AFF0,
            0x1AFF3,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan T
        (
            0x1AFF5,
            0x1AFFB,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan N
        (
            0x1AFFD,
            0x1AFFE,
        ),  # Katakana Letter Minnan N..Katakana Letter Minnan N
        (
            0x1B000,
            0x1B122,
        ),  # Katakana Letter Archaic ..Katakana Letter Archaic
        (
            0x1B132,
            0x1B132,
        ),  # Hiragana Letter Small Ko
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B155,
            0x1B155,
        ),  # Katakana Letter Small Ko
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1D300,
            0x1D356,
        ),  # Monogram For Earth      ..Tetragram For Fostering
        (
            0x1D360,
            0x1D376,
        ),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D7,
        ),  # Hindu Temple            ..Elevator
        (
            0x1F6DC,
            0x1F6DF,
        ),  # Wireless                ..Ring Buoy
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FC,
        ),  # Scooter                 ..Roller Skate
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F7F0,
            0x1F7F0,
        ),  # Heavy Equals Sign
        (
            0x1F90C,
            0x1F93A,
        ),  # Pinched Fingers         ..Fencer
        (
            0x1F93C,
            0x1F945,
        ),  # Wrestlers               ..Goal Net
        (
            0x1F947,
            0x1F9FF,
        ),  # First Place Medal       ..Nazar Amulet
        (
            0x1FA70,
            0x1FA7C,
        ),  # Ballet Shoes            ..Crutch
        (
            0x1FA80,
            0x1FA89,
        ),  # Yo-yo                   ..(nil)
        (
            0x1FA8F,
            0x1FAC6,
        ),  # (nil)
        (
            0x1FACE,
            0x1FADC,
        ),  # Moose                   ..(nil)
        (
            0x1FADF,
            0x1FAE9,
        ),  # (nil)
        (
            0x1FAF0,
            0x1FAF8,
        ),  # Hand With Index Finger A..Rightwards Pushing Hand
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
    "17.0.0": (
        # Source: EastAsianWidth-17.0.0.txt
        # Date: 2025-07-24, 00:12:54 GMT
        #
        (
            0x01100,
            0x0115F,
        ),  # Hangul Choseong Kiyeok  ..Hangul Choseong Filler
        (
            0x0231A,
            0x0231B,
        ),  # Watch                   ..Hourglass
        (
            0x02329,
            0x0232A,
        ),  # Left-pointing Angle Brac..Right-pointing Angle Bra
        (
            0x023E9,
            0x023EC,
        ),  # Black Right-pointing Dou..Black Down-pointing Doub
        (
            0x023F0,
            0x023F0,
        ),  # Alarm Clock
        (
            0x023F3,
            0x023F3,
        ),  # Hourglass With Flowing Sand
        (
            0x025FD,
            0x025FE,
        ),  # White Medium Small Squar..Black Medium Small Squar
        (
            0x02614,
            0x02615,
        ),  # Umbrella With Rain Drops..Hot Beverage
        (
            0x02630,
            0x02637,
        ),  # Trigram For Heaven      ..Trigram For Earth
        (
            0x02648,
            0x02653,
        ),  # Aries                   ..Pisces
        (
            0x0267F,
            0x0267F,
        ),  # Wheelchair Symbol
        (
            0x0268A,
            0x0268F,
        ),  # Monogram For Yang       ..Digram For Greater Yin
        (
            0x02693,
            0x02693,
        ),  # Anchor
        (
            0x026A1,
            0x026A1,
        ),  # High Voltage Sign
        (
            0x026AA,
            0x026AB,
        ),  # Medium White Circle     ..Medium Black Circle
        (
            0x026BD,
            0x026BE,
        ),  # Soccer Ball             ..Baseball
        (
            0x026C4,
            0x026C5,
        ),  # Snowman Without Snow    ..Sun Behind Cloud
        (
            0x026CE,
            0x026CE,
        ),  # Ophiuchus
        (
            0x026D4,
            0x026D4,
        ),  # No Entry
        (
            0x026EA,
            0x026EA,
        ),  # Church
        (
            0x026F2,
            0x026F3,
        ),  # Fountain                ..Flag In Hole
        (
            0x026F5,
            0x026F5,
        ),  # Sailboat
        (
            0x026FA,
            0x026FA,
        ),  # Tent
        (
            0x026FD,
            0x026FD,
        ),  # Fuel Pump
        (
            0x02705,
            0x02705,
        ),  # White Heavy Check Mark
        (
            0x0270A,
            0x0270B,
        ),  # Raised Fist             ..Raised Hand
        (
            0x02728,
            0x02728,
        ),  # Sparkles
        (
            0x0274C,
            0x0274C,
        ),  # Cross Mark
        (
            0x0274E,
            0x0274E,
        ),  # Negative Squared Cross Mark
        (
            0x02753,
            0x02755,
        ),  # Black Question Mark Orna..White Exclamation Mark O
        (
            0x02757,
            0x02757,
        ),  # Heavy Exclamation Mark Symbol
        (
            0x02795,
            0x02797,
        ),  # Heavy Plus Sign         ..Heavy Division Sign
        (
            0x027B0,
            0x027B0,
        ),  # Curly Loop
        (
            0x027BF,
            0x027BF,
        ),  # Double Curly Loop
        (
            0x02B1B,
            0x02B1C,
        ),  # Black Large Square      ..White Large Square
        (
            0x02B50,
            0x02B50,
        ),  # White Medium Star
        (
            0x02B55,
            0x02B55,
        ),  # Heavy Large Circle
        (
            0x02E80,
            0x02E99,
        ),  # Cjk Radical Repeat      ..Cjk Radical Rap
        (
            0x02E9B,
            0x02EF3,
        ),  # Cjk Radical Choke       ..Cjk Radical C-simplified
        (
            0x02F00,
            0x02FD5,
        ),  # Kangxi Radical One      ..Kangxi Radical Flute
        (
            0x02FF0,
            0x03029,
        ),  # Ideographic Description ..Hangzhou Numeral Nine
        (
            0x03030,
            0x0303E,
        ),  # Wavy Dash               ..Ideographic Variation In
        (
            0x03041,
            0x03096,
        ),  # Hiragana Letter Small A ..Hiragana Letter Small Ke
        (
            0x0309B,
            0x030FF,
        ),  # Katakana-hiragana Voiced..Katakana Digraph Koto
        (
            0x03105,
            0x0312F,
        ),  # Bopomofo Letter B       ..Bopomofo Letter Nn
        (
            0x03131,
            0x0318E,
        ),  # Hangul Letter Kiyeok    ..Hangul Letter Araeae
        (
            0x03190,
            0x031E5,
        ),  # Ideographic Annotation L..(nil)
        (
            0x031EF,
            0x0321E,
        ),  # Ideographic Description ..Parenthesized Korean Cha
        (
            0x03220,
            0x03247,
        ),  # Parenthesized Ideograph ..Circled Ideograph Koto
        (
            0x03250,
            0x0A48C,
        ),  # Partnership Sign        ..Yi Syllable Yyr
        (
            0x0A490,
            0x0A4C6,
        ),  # Yi Radical Qot          ..Yi Radical Ke
        (
            0x0A960,
            0x0A97C,
        ),  # Hangul Choseong Tikeut-m..Hangul Choseong Ssangyeo
        (
            0x0AC00,
            0x0D7A3,
        ),  # Hangul Syllable Ga      ..Hangul Syllable Hih
        (
            0x0F900,
            0x0FAFF,
        ),  # Cjk Compatibility Ideogr..(nil)
        (
            0x0FE10,
            0x0FE19,
        ),  # Presentation Form For Ve..Presentation Form For Ve
        (
            0x0FE30,
            0x0FE52,
        ),  # Presentation Form For Ve..Small Full Stop
        (
            0x0FE54,
            0x0FE66,
        ),  # Small Semicolon         ..Small Equals Sign
        (
            0x0FE68,
            0x0FE6B,
        ),  # Small Reverse Solidus   ..Small Commercial At
        (
            0x0FF01,
            0x0FF60,
        ),  # Fullwidth Exclamation Ma..Fullwidth Right White Pa
        (
            0x0FFE0,
            0x0FFE6,
        ),  # Fullwidth Cent Sign     ..Fullwidth Won Sign
        (
            0x16FE0,
            0x16FE3,
        ),  # Tangut Iteration Mark   ..Old Chinese Iteration Ma
        (
            0x16FF2,
            0x16FF6,
        ),  # (nil)
        (
            0x17000,
            0x18CD5,
        ),  # (nil)                   ..Khitan Small Script Char
        (
            0x18CFF,
            0x18D1E,
        ),  # (nil)
        (
            0x18D80,
            0x18DF2,
        ),  # (nil)
        (
            0x1AFF0,
            0x1AFF3,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan T
        (
            0x1AFF5,
            0x1AFFB,
        ),  # Katakana Letter Minnan T..Katakana Letter Minnan N
        (
            0x1AFFD,
            0x1AFFE,
        ),  # Katakana Letter Minnan N..Katakana Letter Minnan N
        (
            0x1B000,
            0x1B122,
        ),  # Katakana Letter Archaic ..Katakana Letter Archaic
        (
            0x1B132,
            0x1B132,
        ),  # Hiragana Letter Small Ko
        (
            0x1B150,
            0x1B152,
        ),  # Hiragana Letter Small Wi..Hiragana Letter Small Wo
        (
            0x1B155,
            0x1B155,
        ),  # Katakana Letter Small Ko
        (
            0x1B164,
            0x1B167,
        ),  # Katakana Letter Small Wi..Katakana Letter Small N
        (
            0x1B170,
            0x1B2FB,
        ),  # Nushu Character-1b170   ..Nushu Character-1b2fb
        (
            0x1D300,
            0x1D356,
        ),  # Monogram For Earth      ..Tetragram For Fostering
        (
            0x1D360,
            0x1D376,
        ),  # Counting Rod Unit Digit ..Ideographic Tally Mark F
        (
            0x1F004,
            0x1F004,
        ),  # Mahjong Tile Red Dragon
        (
            0x1F0CF,
            0x1F0CF,
        ),  # Playing Card Black Joker
        (
            0x1F18E,
            0x1F18E,
        ),  # Negative Squared Ab
        (
            0x1F191,
            0x1F19A,
        ),  # Squared Cl              ..Squared Vs
        (
            0x1F200,
            0x1F202,
        ),  # Square Hiragana Hoka    ..Squared Katakana Sa
        (
            0x1F210,
            0x1F23B,
        ),  # Squared Cjk Unified Ideo..Squared Cjk Unified Ideo
        (
            0x1F240,
            0x1F248,
        ),  # Tortoise Shell Bracketed..Tortoise Shell Bracketed
        (
            0x1F250,
            0x1F251,
        ),  # Circled Ideograph Advant..Circled Ideograph Accept
        (
            0x1F260,
            0x1F265,
        ),  # Rounded Symbol For Fu   ..Rounded Symbol For Cai
        (
            0x1F300,
            0x1F320,
        ),  # Cyclone                 ..Shooting Star
        (
            0x1F32D,
            0x1F335,
        ),  # Hot Dog                 ..Cactus
        (
            0x1F337,
            0x1F37C,
        ),  # Tulip                   ..Baby Bottle
        (
            0x1F37E,
            0x1F393,
        ),  # Bottle With Popping Cork..Graduation Cap
        (
            0x1F3A0,
            0x1F3CA,
        ),  # Carousel Horse          ..Swimmer
        (
            0x1F3CF,
            0x1F3D3,
        ),  # Cricket Bat And Ball    ..Table Tennis Paddle And
        (
            0x1F3E0,
            0x1F3F0,
        ),  # House Building          ..European Castle
        (
            0x1F3F4,
            0x1F3F4,
        ),  # Waving Black Flag
        (
            0x1F3F8,
            0x1F3FA,
        ),  # Badminton Racquet And Sh..Amphora
        (
            0x1F400,
            0x1F43E,
        ),  # Rat                     ..Paw Prints
        (
            0x1F440,
            0x1F440,
        ),  # Eyes
        (
            0x1F442,
            0x1F4FC,
        ),  # Ear                     ..Videocassette
        (
            0x1F4FF,
            0x1F53D,
        ),  # Prayer Beads            ..Down-pointing Small Red
        (
            0x1F54B,
            0x1F54E,
        ),  # Kaaba                   ..Menorah With Nine Branch
        (
            0x1F550,
            0x1F567,
        ),  # Clock Face One Oclock   ..Clock Face Twelve-thirty
        (
            0x1F57A,
            0x1F57A,
        ),  # Man Dancing
        (
            0x1F595,
            0x1F596,
        ),  # Reversed Hand With Middl..Raised Hand With Part Be
        (
            0x1F5A4,
            0x1F5A4,
        ),  # Black Heart
        (
            0x1F5FB,
            0x1F64F,
        ),  # Mount Fuji              ..Person With Folded Hands
        (
            0x1F680,
            0x1F6C5,
        ),  # Rocket                  ..Left Luggage
        (
            0x1F6CC,
            0x1F6CC,
        ),  # Sleeping Accommodation
        (
            0x1F6D0,
            0x1F6D2,
        ),  # Place Of Worship        ..Shopping Trolley
        (
            0x1F6D5,
            0x1F6D8,
        ),  # Hindu Temple            ..(nil)
        (
            0x1F6DC,
            0x1F6DF,
        ),  # Wireless                ..Ring Buoy
        (
            0x1F6EB,
            0x1F6EC,
        ),  # Airplane Departure      ..Airplane Arriving
        (
            0x1F6F4,
            0x1F6FC,
        ),  # Scooter                 ..Roller Skate
        (
            0x1F7E0,
            0x1F7EB,
        ),  # Large Orange Circle     ..Large Brown Square
        (
            0x1F7F0,
            0x1F7F0,
        ),  # Heavy Equals Sign
        (
            0x1F90C,
            0x1F93A,
        ),  # Pinched Fingers         ..Fencer
        (
            0x1F93C,
            0x1F945,
        ),  # Wrestlers               ..Goal Net
        (
            0x1F947,
            0x1F9FF,
        ),  # First Place Medal       ..Nazar Amulet
        (
            0x1FA70,
            0x1FA7C,
        ),  # Ballet Shoes            ..Crutch
        (
            0x1FA80,
            0x1FA8A,
        ),  # Yo-yo                   ..(nil)
        (
            0x1FA8E,
            0x1FAC6,
        ),  # (nil)
        (
            0x1FAC8,
            0x1FAC8,
        ),  # (nil)
        (
            0x1FACD,
            0x1FADC,
        ),  # (nil)
        (
            0x1FADF,
            0x1FAEA,
        ),  # (nil)
        (
            0x1FAEF,
            0x1FAF8,
        ),  # (nil)                   ..Rightwards Pushing Hand
        (
            0x20000,
            0x2FFFD,
        ),  # Cjk Unified Ideograph-20..(nil)
        (
            0x30000,
            0x3FFFD,
        ),  # Cjk Unified Ideograph-30..(nil)
    ),
}
